# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.chart2
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_chart_type import XChartType as XChartType_ad200b38

class XChartTypeContainer(XInterface_8f010a43):
    """

    See Also:
        `API XChartTypeContainer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart2_1_1XChartTypeContainer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.XChartTypeContainer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart2.XChartTypeContainer'

    @abstractmethod
    def addChartType(self, aChartType: 'XChartType_ad200b38') -> None:
        """
        add a chart type to the chart type container

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getChartTypes(self) -> 'typing.Tuple[XChartType_ad200b38, ...]':
        """
        retrieve all chart types
        """
        ...
    @abstractmethod
    def removeChartType(self, aChartType: 'XChartType_ad200b38') -> None:
        """
        removes one data series from the chart type container.

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...
    @abstractmethod
    def setChartTypes(self, aChartTypes: 'typing.Tuple[XChartType_ad200b38, ...]') -> None:
        """
        set all chart types

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['XChartTypeContainer']

