# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.io
from .x_active_data_sink import XActiveDataSink as XActiveDataSink_b8d00ba3
from .x_connectable import XConnectable as XConnectable_980a0a96
from .x_data_input_stream import XDataInputStream as XDataInputStream_c56e0c2e

class DataInputStream(XActiveDataSink_b8d00ba3, XConnectable_980a0a96, XDataInputStream_c56e0c2e):
    """
    Service Class

    reads structured data from a chained XInputStream.
    
    An implementation of this service in general does not need to buffer data itself.

    See Also:
        `API DataInputStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1io_1_1DataInputStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.DataInputStream'
    __ooo_type_name__: str = 'service'



__all__ = ['DataInputStream']

