# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.sdb
from ..container.x_hierarchical_name import XHierarchicalName as XHierarchicalName_3a4b0f63
from ..ucb.content import Content as Content_70d9091d

class DefinitionContent(Content_70d9091d, XHierarchicalName_3a4b0f63):
    """
    Service Class

    defines the basic functionality for an object in the hierarchy of sub documents of an OfficeDatabaseDocument.
    
    **since**
    
        OOo 3.3

    See Also:
        `API DefinitionContent <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DefinitionContent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DefinitionContent'
    __ooo_type_name__: str = 'service'



__all__ = ['DefinitionContent']

