# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class KeyFunction(metaclass=UnoConstMeta, type_name="com.sun.star.awt.KeyFunction", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.KeyFunction``"""
        pass

    class KeyFunctionEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.KeyFunction", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.KeyFunction`` as Enum values"""
        pass

else:
    from ...lo.awt.key_function import KeyFunction as KeyFunction

    class KeyFunctionEnum(IntEnum):
        """
        Enum of Const Class KeyFunction

        These values are used to specify logical key functions.
        """
        DONTKNOW = KeyFunction.DONTKNOW
        NEW = KeyFunction.NEW
        OPEN = KeyFunction.OPEN
        SAVE = KeyFunction.SAVE
        SAVEAS = KeyFunction.SAVEAS
        PRINT = KeyFunction.PRINT
        CLOSE = KeyFunction.CLOSE
        QUIT = KeyFunction.QUIT
        CUT = KeyFunction.CUT
        COPY = KeyFunction.COPY
        PASTE = KeyFunction.PASTE
        UNDO = KeyFunction.UNDO
        REDO = KeyFunction.REDO
        DELETE = KeyFunction.DELETE
        REPEAT = KeyFunction.REPEAT
        FIND = KeyFunction.FIND
        FINDBACKWARD = KeyFunction.FINDBACKWARD
        PROPERTIES = KeyFunction.PROPERTIES
        FRONT = KeyFunction.FRONT

__all__ = ['KeyFunction', 'KeyFunctionEnum']
