# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.3
# Namespace: com.sun.star.reflection
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_idl_class import XIdlClass as XIdlClass_d63a0c9a

class XIdlMember(XInterface_8f010a43):
    """
    Base interface for XIdlField2s and XIdlMethods.

    See Also:
        `API XIdlMember <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XIdlMember.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.reflection'
    __ooo_full_ns__: str = 'com.sun.star.reflection.XIdlMember'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.reflection.XIdlMember'

    @abstractmethod
    def getDeclaringClass(self) -> 'XIdlClass_d63a0c9a':
        """
        Returns the declaring type of this field, i.e.
        
        the type having the member declared (interface, enum, struct, exception).
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        Returns the fully-qualified name of the member.
        """
        ...

__all__ = ['XIdlMember']

